@@ -63,8 +63,8 @@ mimelist <- list (
 	"h"="text/x-c",
 	"htc"="text/x-component",
 	"hh"="text/x-c",
-	"htm"="text/html; charset=UTF-8",
-	"html"="text/html; charset=UTF-8",
+	"htm"="text/html; charset=utf-8",
+	"html"="text/html; charset=utf-8",
 	"ico"="image/vnd.microsoft.icon",
 	"ics"="text/calendar",
 	"ifb"="text/calendar",
@@ -76,7 +76,7 @@ mimelist <- list (
 	"jpg"="image/jpeg",
 	"js"="application/javascript",
 	"json"="application/json",
-	"log"="text/plain; charset=UTF-8",
+	"log"="text/plain; charset=utf-8",
 	"m3u"="audio/x-mpegurl",
 	"m4v"="video/mp4",
 	"man"="text/troff",
@@ -150,12 +150,12 @@ mimelist <- list (
 	"tex"="application/x-tex",
 	"texi"="application/x-texinfo",
 	"texinfo"="application/x-texinfo",
-	"text"="text/plain; charset=UTF-8",
+	"text"="text/plain; charset=utf-8",
 	"tif"="image/tiff",
 	"tiff"="image/tiff",
 	"torrent"="application/x-bittorrent",
 	"tr"="text/troff",
-	"txt"="text/plain; charset=UTF-8",
+	"txt"="text/plain; charset=utf-8",
 	"vcf"="text/x-vcard",
 	"vcs"="text/x-vcalendar",
 	"vrml"="model/vrml",
