@@ -1,9 +1,6 @@
 #this function is called by a cronjob
 #not used by the API
-updategithub <- function(){
-  #import
-  eval.secure <- from("RAppArmor", "eval.secure");  
-  
+updategithub <- function(){  
   #make sure config is initiated
   loadconfigs();
     
@@ -28,7 +25,7 @@ updategithub <- function(){
     pkg <- strsplit(x, "_", fixed=TRUE)[[1]];
     
     #Update github packages
-    result <- eval.secure(github_install(pkg[4], pkg[3]), timeout=30*60, RLIMIT_CPU=30*60, RLIMIT_AS = 2e9, profile="opencpu-main");  
+    result <- RAppArmor::eval.secure(github_install(pkg[4], pkg[3]), timeout=30*60, RLIMIT_CPU=30*60, RLIMIT_AS = 2e9, profile="opencpu-main");  
   
     #cat some output
     try(cat("Github update of", pkg[3], "/", pkg[4], ": ", ifelse(result$success, "successful.\n", "failed.\n")));
